## Sid Meier's Civilization 4
## Copyright Firaxis Games 2005
from CvPythonExtensions import *
import CvUtil
import CvTechChooser
import traceback
import os
import sys
import PyHelpers
import GodsOfOld
import pickle
import CvGameUtils
import CvEventInterface

# for C++ compatibility
false=False
true=True

# globals
gc = CyGlobalContext()
PyPlayer = PyHelpers.PyPlayer
RELIGIOUS_TECH_MAX_RELIGIONS = {}
bReligiousTechInitDone = False
LR_iPlayer = gc.getGame().getActivePlayer()

# Orion's Inquisition Mod
def isOC_LIMITED_RELIGIONS():
	return gc.getDefineINT("OC_LIMITED_RELIGIONS") != 0
	
def isOC_FOREIGN_INQUISITIONS():
	return gc.getDefineINT("OC_FOREIGN_INQUISITIONS") != 0
	
def	isOC_RESPAWN_HOLY_CITIES():
	return gc.getDefineINT("OC_RESPAWN_HOLY_CITIES") != 0
	
def	isOC_INQUISITOR_CAN_REMOVE_HOLY_CITY():
	return gc.getDefineINT("OC_INQUISITOR_CAN_REMOVE_HOLY_CITY") != 0

def doReligiousUnityCheck(iPlayer):
	# Code to determine if all cities have 6 "Religious Unity" Prerequisites by Orion Veteran
	# Special thanks to STO for providing the code strategy - Great Job! 
	# 1. A player must have an official State Religion
	# 2. A player must have the Holy City for the official State Religion	
	# 3. A player must have built the Shrine for the official State Religion			
	# 4. All of a player's cities must have the official state religion established.
	# 5. All of a player's cities must not have any non-state religions established.
	# 6. Religious influence must be at least 80%
	pPlayer = gc.getPlayer(iPlayer)

	# Is the "Religious" victory game option set to True?
	if CyGame().isVictoryValid(gc.getInfoTypeForString("VICTORY_RELIGIOUS")) :
		if (pPlayer.getNumCities() > 0) and (CyGame().getNumCivCities() > 2 * CyGame().countCivPlayersAlive()): # be sure the game is advanced enough to test a religious victory
			bUnity = True
			iStateReligion = pPlayer.getStateReligion()
			
			if iStateReligion == -1 :
				# No State Religion was Found - Prerequisite 1
				#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'No State Religion!','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
				bUnity = False
				
			if bUnity :				
				if not pPlayer.hasHolyCity(iStateReligion) :
					# No Holy City was Found for the official state religion - Prerequisite 2
					#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'Holy City Not Found!','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
					bUnity = False
		
			if bUnity :
				MyShrine = getReligionShrine(iStateReligion)
				
				if MyShrine != -1:
					if not hasStateReligionShrine(iPlayer):
						# No official State Religion Shrine was found for the official state religion - Prerequisite 3
						bUnity = False
										
			if bUnity :
						
				for pyCity in PyHelpers.PyPlayer(iPlayer).getCityList() :
					if not bUnity :
						break
				
					for iReligionLoop in range(gc.getNumReligionInfos()):
						if iReligionLoop == iStateReligion :
							if not pyCity.hasReligion(iReligionLoop) :
								# City does not have the official state religion - Prerequisite 4
								#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'No State Religion founded in City!','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
								bUnity = False
								break
						elif pyCity.hasReligion(iReligionLoop) :
							# City has a non-State religion - Prerequisite 5
							if not isOC_INQUISITOR_CAN_REMOVE_HOLY_CITY():
								if not isHoly(pyCity):
									bUnity = False
									break
							else:	
								#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'Found non-State Religion!','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
								bUnity = False
								break
								
			if bUnity :
				if CyGame().calculateReligionPercent(iStateReligion) < 80 :
					# Religeous influence is less than 80% - Prerequisite 6
					#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'No Religion influence!','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
					bUnity = False							

			if bUnity :
				# The player has met all 6 prerequsites to achieve a valid religeous victory
				#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'Victory!','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
				CyGame().setWinner(pPlayer.getTeam(), gc.getInfoTypeForString("VICTORY_RELIGIOUS"))
	
	return

def RemoveAllNonStateReligiousBuildings(pPlayer, iStateReligion, pCity):
	# Removes all non-state religious buildings from the City
	iGoldTotal = 0
	iPlayer = pPlayer.getID( )
	
	for iBuildingLoop in range(gc.getNumBuildingInfos( )):
		if pCity.isHasBuilding( iBuildingLoop ):
			pBuilding = gc.getBuildingInfo( iBuildingLoop )
			iRequiredReligion = pBuilding.getReligionType( )
			for iReligionLoop in range(gc.getNumReligionInfos()):
				if iReligionLoop != pPlayer.getStateReligion( ):
					if iRequiredReligion == iReligionLoop:
						if OCHasNonStateShrine(pPlayer, iBuildingLoop):
							# Greatly increases Anger for all AIs who share the religion of the destroyed Shrine
							AIAttitudeAdjustment(iPlayer, iRequiredReligion, -3, True)
							# Removes Building
							pCity.setNumRealBuilding ( iBuildingLoop,0 )
							# Add gold to treasury for pillaging the non-state Shrine
							iGoldTotal = iGoldTotal + 500
							CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'Destruction of a non-state Holy Shrine has angered one or more AI Civs!','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(7),0,0,False,False)
							# Add code to increase shrine income
						else:											
							# Removes Building
							pCity.setNumRealBuilding ( iBuildingLoop,0 )
							# Add gold to treasury for pillaging the non-state Religious Building									
							iGoldTotal = iGoldTotal + 250
							# Increases Anger for all AIs who share the religion of a destroyed Temple, Monastery or Cathedral
							AIAttitudeAdjustment(iPlayer, iRequiredReligion, -1, False)
	
	# Total Pillage Reward	
	pPlayer.changeGold(iGoldTotal)
	#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'All non-state religious buildings were removed!','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)


def RemoveAllNonStateReligions(pPlayer, iStateReligion, pCity):
	# Removes all non-state religions and Holy City identifier from City			
	iGoldTotal = 0
	iPlayer = pPlayer.getID( )
	
	for iReligionLoop in range(gc.getNumReligionInfos()):
		# Make sure only non-state religions are selected
		if iReligionLoop != iStateReligion:
			# Is this a non-state Holy City?
			if pCity.isHolyCityByType( iReligionLoop ):
				# Check default -- Does game option allow removal of a Holy City?
				if isOC_INQUISITOR_CAN_REMOVE_HOLY_CITY():
					# Increases Anger for all AIs who share the purged Holy City
					AIAttitudeAdjustment(iPlayer, iReligionLoop, -3, True)
					# Remove non-state Holy City identifier
					gc.getGame( ).clearHolyCity( iReligionLoop )
					# Add gold to treasury for pillaging the non-state Holy City
					iGoldTotal = iGoldTotal + 500
					# Increases Anger for all AIs who share the purged religion						
					AIAttitudeAdjustment(iPlayer, iReligionLoop, -1, False)
					# Remove non-state religion
					pCity.setHasReligion(iReligionLoop, 0, 0, 0)
					# Add gold to treasury to compensate for inquisition costs
					iGoldTotal = iGoldTotal + 100
					CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'Destruction of a non-state Holy City has angered one or more AI Civs!','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(7),0,0,False,False)
					# Set Minimum of Two Cities required for Respawning a Holy City
					minCitiesForInfluence = 2
					# Check default -- Respawn Holy City?
					
					if isOC_RESPAWN_HOLY_CITIES():
						# Find player with the at least 2 Cities of religious influence to respawn the Holy City.                   
						eBestPlayer = getPlayerWithMaxInfluenceForReligion(iReligionLoop, minCitiesForInfluence)
						# If there is a player with enough Religious Influence for Religion
						if eBestPlayer >= 0:
							XpPlayer = gc.getPlayer(eBestPlayer)
							# Respawn the Holy City
							ReSpawnHolyCity(XpPlayer, iReligionLoop)
																		
			elif pCity.isHasReligion( iReligionLoop ):
				# Increases Anger for all AIs who share the purged religion						
				AIAttitudeAdjustment(iPlayer, iReligionLoop, -1, False)
				# Remove non-state religion
				pCity.setHasReligion(iReligionLoop, 0, 0, 0)
				# Add gold to treasury to compensate for inquisition costs						
				iGoldTotal = iGoldTotal + 100

	# Persecution succeeds
	# Total Pillage Reward
	pPlayer.changeGold(iGoldTotal)
	#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'All non-state religions were removed!','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)

def FoundLimitedReligions(iPlayer, iTechType):
	#Controls the founding of religions
	# Inquisition Mod
	rSlotAvailable = False
	iRCount = 0
	CvPlayer = gc.getPlayer(iPlayer)
		
	# Is Tech a Religious Tech?
	if CvIsReligiousTech(iTechType):
		# If game option is Limited Religions
		if isOC_LIMITED_RELIGIONS():
			if not CvPlayer.isNone() and not CvPlayer.isBarbarian() and CvPlayer.isAlive():
				# Does the player have a Holy City?
				if not OwnsHolyCity(iPlayer):
					# Loop through Religions
					for iReligion in range(gc.getNumReligionInfos()):
						# If the religion has not been founded
						if not gc.getGame().isReligionFounded(iReligion):
							# If game option is not set to choose religions
							if not CyGame().isOption(GameOptionTypes.GAMEOPTION_PICK_RELIGION):
								if gc.getReligionInfo(iReligion).getTechPrereq() == iTechType:
									gc.getPlayer(iPlayer).foundReligion(iReligion,iReligion,True)
									#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'Message A','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
									break
							# If game option is set to choose religions
							elif CyGame().isOption(GameOptionTypes.GAMEOPTION_PICK_RELIGION):
								rSlotAvailable = True
								break
		
	#  There is one or more unfounded Religions
	if rSlotAvailable:
		TotalRelFounded = CvGetTotalReligionsFounded()
		# Evaluate whether or not a religion can be founded for the discovered tech 
		if canTechFoundReligion(iTechType, TotalRelFounded):
			if not CvPlayer.isNone() and not CvPlayer.isBarbarian() and not CvPlayer.isHuman() and CvPlayer.isAlive():
				if not OwnsHolyCity(iPlayer):
					gc.getPlayer(iPlayer).foundReligion(iReligion,iReligion,True)
					#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'Message B','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)

			elif CvPlayer.isHuman() and CvPlayer.isAlive():
				# Create Religion Selection Popup
				popupInfo = CyPopupInfo()
				popupInfo.setButtonPopupType(ButtonPopupTypes.BUTTONPOPUP_PYTHON)
				popupInfo.setData1(iPlayer)
				popupInfo.setText(CyTranslator().getText(("TXT_KEY_FOUNDED_RELIGION"),()))
								
				# Find all unfounded religions
				for iNewReligion in range(gc.getNumReligionInfos()):
					if not gc.getGame().isReligionFounded(iNewReligion):
						popupInfo.addPythonButton(gc.getReligionInfo(iNewReligion).getDescription(), gc.getReligionInfo(iNewReligion).getButton())
						iRCount = iRCount + 1
						if iRCount == gc.getNumReligionInfos() - CvGetTotalReligionsFounded():
							# Display popup for human player to selected Religion
							popupInfo.addPopup(1)
							#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'Message C','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
							break
							# End Inquisition Mod
							
	return						
		
def OwnsHolyCity(iPlayer):
	#Checks to see if player has a Holy City
	#Returns True if player has a Holy City
	#Returns False if player does not have a Holy City
	pHolyCity = False
	pPlayer = gc.getPlayer(iPlayer)
	
	for iCity in range(pPlayer.getNumCities()):
		pCity = pPlayer.getCity(iCity)
		
		for iRel in range(gc.getNumReligionInfos()):
			if pCity.isHasReligion(iRel):
				if pCity.isHolyCityByType(iRel):
					#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'Holy City Found!','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
					pHolyCity = True
					break
	
	return pHolyCity
		
def hasMatchingStateReligion(iPlayerA, iPlayerB):
	#Checks for matching state religion between two players
	#Returns True if both players have the same state religion
	#Returns False if both players do not have the same state religion
	pPlayerA = gc.getPlayer(iPlayerA)
	pPlayerB = gc.getPlayer(iPlayerB)
	iStateReligionA = pPlayerA.getStateReligion()
	iStateReligionB = pPlayerB.getStateReligion()
		
	if iStateReligionA == iStateReligionB:
		return True
	
	return False
	
def hasOpenBordersAgreement (iPlayerA, iPlayerB):
	#Check for Open Borders Agreement between two players.
	#Returns True if Open Borders Agreement Exists.
	#Returns False if Open Borders Agreement does not Exist.
	MyAgreement = False
		
	for iMyDeal in range(gc.getGame().getIndexAfterLastDeal()):
		deal = gc.getGame().getDeal(iMyDeal)
		if ((deal.getFirstPlayer() == iPlayerA and deal.getSecondPlayer() == iPlayerB) and not deal.isNone() or (deal.getSecondPlayer() == iPlayerB and deal.getFirstPlayer() == iPlayerA)) and not deal.isNone():
			for jTrade in range(deal.getLengthFirstTrades()):
				tradeData = deal.getFirstTrade(jTrade)
				if tradeData.ItemType == TradeableItems.TRADE_OPEN_BORDERS:
					MyAgreement = True
					break
						
	if MyAgreement:
		#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'Open Borders Agreement!','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
		return True
	else:
		#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'No Open Borders Agreement!','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
		return False

def onTechPreviouslyFounded(MyTechType):
	pdTech = False	
	# Check to see if tech has been previously discovered
	for ePlayer in range(gc.getMAX_CIV_PLAYERS()):
		PyPlayer = gc.getPlayer(ePlayer)
		if (gc.getPlayer(ePlayer).isAlive()):
			if ePlayer != gc.getPlayer(CyGame().getActivePlayer()).getID():
				if gc.getTeam(PyPlayer.getTeam()).isHasTech(MyTechType):
					# True if tech has been previously discovered
					pdTech = True
					break
						
	if not pdTech:
		#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'Tech was not previously discovered!','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
		return False
	else:
		#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'Tech was previously discovered!','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
		return True

def isHoly(iCity):

	HCConfirmed = False

	for iReligion in range(gc.getNumReligionInfos()):
		# Confirm City is a Holy City and get the religion
		if iCity.isHolyCityByType(iReligion):
			HCConfirmed = True
			break
	
	return HCConfirmed
	
def getHolyCityReligion(iCity):
		
	for iReligion in range(gc.getNumReligionInfos()):
		# Confirm City is a Holy City and get the religion
		if iCity.isHolyCityByType(iReligion):
			MyHCReligion = iReligion
			break	
	
	return MyHCReligion

def isReligionExist(iReligion):
	#checks if the religion exists anywhere in the world
	#regardless of whether it has a founding holy city or not
	for rPlayer in range(gc.getMAX_PLAYERS()):
		RyPlayer = gc.getPlayer(rPlayer)
		if RyPlayer.isAlive():
			if RyPlayer.getHasReligionCount(iReligion):
				return True
				
	return False

def OwnsHolyCity(iPlayer):
	#Checks to see if player has a Holy City
	#Returns True if player has a Holy City
	#Returns False if player does not have a Holy City
	pHolyCity = False
	pPlayer = gc.getPlayer(iPlayer)
			
	for iCity in range(pPlayer.getNumCities()):
		pCity = pPlayer.getCity(iCity)
		
		for iRel in range(gc.getNumReligionInfos()):
			if pCity.isHasReligion(iRel):
				if pCity.isHolyCityByType(iRel):
					#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'Holy City Found!','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
					pHolyCity = True
					break

	return pHolyCity

def getBestReligion():
	
	lReligions = [ ]
	iBestReligionPercent = 0
	iBestReligion = -1
	
	#Checks religion percents	
	for iReligionLoop in range(gc.getNumReligionInfos( )):
		iReligionPercent = gc.getGame().calculateReligionPercent(iReligionLoop)			
		lReligions.append( iReligionLoop )
		if iReligionPercent > iBestReligionPercent:
			iBestReligionPercent = iReligionPercent
			iBestReligion = iReligionLoop						

	return iBestReligion
	
def getBestReligionPercent():
	
	lReligions = [ ]
	iBestReligionPercent = 0
		
	#Checks religion percents	
	for iReligionLoop in range(gc.getNumReligionInfos( )):
		iReligionPercent = gc.getGame().calculateReligionPercent(iReligionLoop)			
		lReligions.append( iReligionLoop )
		if iReligionPercent > iBestReligionPercent:
			iBestReligionPercent = iReligionPercent
			
	return iBestReligionPercent	
	
def getPlayerWithMaxInfluenceForReligion(MyHCReligion, minCitiesRequired):
	eBestPlayer = -1
	iBestCount = 0
	
	for ePlayer in range(gc.getMAX_PLAYERS()):
		pPlayer = gc.getPlayer(ePlayer)
		# skip invalid or dead players
		if not pPlayer.isNone():
			if pPlayer.isAlive():
				iCount = pPlayer.getHasReligionCount(MyHCReligion)
				if iCount > iBestCount:
					iBestCount = iCount
					eBestPlayer = ePlayer
	
	if iBestCount >= minCitiesRequired:
		return eBestPlayer
	else:
		return -1

def ocCityHasNonStateReligion(ocCity, ocStateReligion):
	iCount = 0
	
	for iocReligionLoop in range(gc.getNumReligionInfos( )):
		if ocCity.isHasReligion( iocReligionLoop ):
			if iocReligionLoop != ocStateReligion:
				# Must not be a Holy City Religion - Only a non-state religion
				if not ocCity.isHolyCityByType(iocReligionLoop):
					iCount = iCount + 1  
	
	if iCount > 0:
		return True
	else:
		return False

def ReSpawnHolyCity(XpPlayer, MyHCReligion):
	RHC = False
	
	# Execute Relocation of Holy City 
	for iCity in range(XpPlayer.getNumCities()):
		XpCity = XpPlayer.getCity(iCity)
		for iReligion1 in range(gc.getNumReligionInfos()):
			if MyHCReligion == iReligion1:
				if XpCity.isHasReligion(MyHCReligion):
					RHC = True
					break
												
		if RHC:
			CyGame().setHolyCity(MyHCReligion, XpCity, True)
			CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'A Holy City Religion has been Respawned','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
			break
			
def CvGetTotalReligionsFounded():
	MyReligionCount  = 0

	for ixReligion in range(gc.getNumReligionInfos()):
		#If the religion has not been founded 
		if gc.getGame().isReligionFounded(ixReligion):
			MyReligionCount = MyReligionCount + 1
	
	#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'Total Religious Techs founded' [iReligionCount],'AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
	return MyReligionCount

def CvIsReligiousTech(iTechType):
	ReligiousTech = False
	
	for iREL in range(gc.getNumReligionInfos()):
		if gc.getReligionInfo(iREL).getTechPrereq() == iTechType:
			ReligiousTech = True
			break
			
	return ReligiousTech
		
def findCityWithXReligion(xReligion):
	MyXCityCount = 0
	FoundReligion = False
		
	for iPlayer in range(gc.getMAX_PLAYERS()):		
		pPlayer = gc.getPlayer(iPlayer)				
		if pPlayer.isAlive() and not pPlayer.isBarbarian():
			lCities = PyHelpers.PyPlayer(iPlayer).getCityList()
			for iCity in range( len( lCities ) ):				
				pCity = pPlayer.getCity( lCities[ iCity ].getID( ) )
				for iReligionX in range(gc.getNumReligionInfos()):
					if iReligionX == xReligion: 						
						if pCity.isHasReligion(xReligion):
							if not pCity.isHolyCityByType(xReligion):
								MyXCityCount = MyXCityCount + 1
								FoundReligion = True
								break
						
		if MyXCityCount > 0:		
			break
							
	if not FoundReligion:	
		#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'False!','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
		return False
	else:	
		#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'True!','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
		return True

def CvAddBuilding(pCity, CvBuildingClass):
	# Add specified building to specified City
	iBuilding = gc.getInfoTypeForString(CvBuildingClass)
	iUniqueBuilding = gc.getCivilizationInfo(gc.getPlayer(pCity.getOwner()).getCivilizationType()).getCivilizationBuildings(iBuilding)
	if iUniqueBuilding > -1:
		if pCity.canConstruct(iUniqueBuilding, False, True, False):
			pCity.setNumRealBuilding(iUniqueBuilding, 1)

def CvHasBuilding(iPlayer, strBuilding):
	# Returns True if player has the specified Building
	# Returns False if player does not have the specified Building
	pPlayer = gc.getPlayer(iPlayer)
	HasStrBuilding = False
	
	for iCity in range(pPlayer.getNumCities()):
		pCity = pPlayer.getCity(iCity)
		if pCity.isHasBuilding(gc.getInfoTypeForString(strBuilding)):
			#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'Found Building','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
			HasStrBuilding = True
			break
			
	return HasStrBuilding

def isBuildingObsolete(iPlayer, strBuilding):
	# Returns True if the obsolete Tech for a specified building has been discovered
	# Returns False if obsolete Tech for a specified building has not been discovered
	pPlayer = gc.getPlayer(iPlayer)
	Building = gc.getInfoTypeForString(strBuilding)
	obsoleteTech = gc.getBuildingInfo(Building).getObsoleteTech()
	
	if ( gc.getTeam(pPlayer.getTeam()).isHasTech(obsoleteTech) == False or obsoleteTech == -1 ):
		return False
		
	return True

def doWonderCheck(iPlayer):			
	#if CvHasBuilding(iPlayer, "BUILDING_PETRA_MONASTERY"):
	#	addStateReligionMonasteryAllCities(iPlayer)
	
	if CvHasBuilding(iPlayer, "BUILDING_WITCHES_HAMMER"):
		if not isBuildingObsolete(iPlayer, "BUILDING_WITCHES_HAMMER"):
			addStateReligionTempleAllCities(iPlayer)
		
# Witches Hammer Wonder
def CannotSpreadNonStateReligion(iReligion, iX, iY):		
	pPlot = CyMap().plot(iX, iY)
	iPlayer = pPlot.getOwner()
	pPlayer = gc.getPlayer(iPlayer)
	
	if not isBuildingObsolete(iPlayer, "BUILDING_WITCHES_HAMMER"):
		if CvHasBuilding(iPlayer, "BUILDING_WITCHES_HAMMER"):
			if pPlayer.getStateReligion( ) != iReligion:
				return True
	
	return False
# End Witches Hammer Wonder
	
# Petra Monastery Wonder
def addStateReligionMonasteryAllCities(iPlayer):
	pPlayer = gc.getPlayer(iPlayer)
	iStateReligion = pPlayer.getStateReligion()
	
	for iCity in range(pPlayer.getNumCities()):
		pCity = pPlayer.getCity(iCity)
		MyMonastery = str(getReligionMonastery(iStateReligion))
		if not pCity.isHasBuilding(gc.getInfoTypeForString(MyMonastery)):
			pCity.setNumRealBuilding(gc.getInfoTypeForString(MyMonastery), 1)
	
	return	

def getReligionMonastery(iStateReligion):	
	# Returns the Religion Monastery for the specified State Religion
	rMonastery = -1	
	ldata = {
		"RELIGION_JUDAISM": "BUILDING_JEWISH_MONASTERY",
		"RELIGION_CHRISTIANITY": "BUILDING_CHRISTIAN_MONASTERY",
		"RELIGION_ISLAM": "BUILDING_ISLAMIC_MONASTERY",
		"RELIGION_HINDUISM": "BUILDING_HINDU_MONASTERY",
		"RELIGION_BUDDHISM": "BUILDING_BUDDHIST_MONASTERY",
		"RELIGION_CONFUCIANISM": "BUILDING_CONFUCIAN_MONASTERY",
		"RELIGION_TAOISM": "BUILDING_TAOIST_MONASTERY"
	}

	for szReligion, iMonastery in ldata.iteritems():
		iReligion = gc.getInfoTypeForString(szReligion)
		if iReligion == iStateReligion:
			rMonastery = str(iMonastery)
			#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,str(iMonastery),'AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
			break
		
	return str(iMonastery)
# End Petra Monastery Wonder

def CTFRinit():
	global bReligiousTechInitDone
	if not bReligiousTechInitDone:
		data = {
			"TECH_MEDITATION": 2,
			"TECH_POLYTHEISM": 2,
			"TECH_MONOTHEISM": 3,
			"TECH_CODE_OF_LAWS": 5,
			"TECH_THEOLOGY": 5,
			"TECH_PHILOSOPHY": 7,
			"TECH_DIVINE_RIGHT": 7
		}
		for szTech, iMax in data.iteritems():
			iTech = gc.getInfoTypeForString(szTech)
			if iTech != -1:
				RELIGIOUS_TECH_MAX_RELIGIONS[iTech] = iMax
		bReligiousTechInitDone = True
		
def canTechFoundReligion(iTechType, intRelFounded):
	CTFRinit()
	return intRelFounded < RELIGIOUS_TECH_MAX_RELIGIONS.get(iTechType, 0)

# ###################################################################################################################
def getReligionInquisitor(iStateReligion):
	# Returns the Religion Inquisitor for the specified State Religion
	rInquisitor = -1
	ldata = {
		"RELIGION_JUDAISM": "UNIT_JEWISH_INQUISITOR",
		"RELIGION_CHRISTIANITY": "UNIT_CHRISTIAN_INQUISITOR",
		"RELIGION_ISLAM": "UNIT_ISLAMIC_INQUISITOR",
		"RELIGION_HINDUISM": "UNIT_HINDU_INQUISITOR",
		"RELIGION_BUDDHISM": "UNIT_BUDDHIST_INQUISITOR",
		"RELIGION_CONFUCIANISM": "UNIT_CONFUCIAN_INQUISITOR",
		"RELIGION_TAOISM": "UNIT_TAOIST_INQUISITOR"
	}

	for szReligion, iInquisitor in ldata.iteritems():
		iReligion = gc.getInfoTypeForString(szReligion)
		if iReligion == iStateReligion:
			rInquisitor = str(iInquisitor)
			#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,str(iInquisitor),'AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
			break
	
	return str(iInquisitor)
	
def getReligionHolyOffice(iStateReligion):
	# Returns the Religion HOLY OFFICE building for the specified State Religion
	rHolyOffice = -1
	
	ldata = {
		"RELIGION_JUDAISM": "BUILDING_JEWISH_HOLY_OFFICE",
		"RELIGION_CHRISTIANITY": "BUILDING_CHRISTIAN_HOLY_OFFICE",
		"RELIGION_ISLAM": "BUILDING_ISLAMIC_HOLY_OFFICE",
		"RELIGION_HINDUISM": "BUILDING_HINDU_HOLY_OFFICE",
		"RELIGION_BUDDHISM": "BUILDING_BUDDHIST_HOLY_OFFICE",
		"RELIGION_CONFUCIANISM": "BUILDING_CONFUCIAN_HOLY_OFFICE",
		"RELIGION_TAOISM": "BUILDING_TAOIST_HOLY_OFFICE"
	}

	for szReligion, iHolyOffice in ldata.iteritems():
		iReligion = gc.getInfoTypeForString(szReligion)
		if iReligion == iStateReligion:
			rHolyOffice = str(iHolyOffice)
			#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,str(iHolyOffice),'AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
			break
		
	return str(iHolyOffice)	
	
def getReligionTemple(iStateReligion):
	# Returns the Religion Temple for the specified State Religion
	rTemple = -1
	
	ldata = {
		"RELIGION_JUDAISM": "BUILDING_JEWISH_TEMPLE",
		"RELIGION_CHRISTIANITY": "BUILDING_CHRISTIAN_TEMPLE",
		"RELIGION_ISLAM": "BUILDING_ISLAMIC_TEMPLE",
		"RELIGION_HINDUISM": "BUILDING_HINDU_TEMPLE",
		"RELIGION_BUDDHISM": "BUILDING_BUDDHIST_TEMPLE",
		"RELIGION_CONFUCIANISM": "BUILDING_CONFUCIAN_TEMPLE",
		"RELIGION_TAOISM": "BUILDING_TAOIST_TEMPLE"
	}

	for szReligion, iTemple in ldata.iteritems():
		iReligion = gc.getInfoTypeForString(szReligion)
		if iReligion == iStateReligion:
			rTemple = str(iTemple)
			#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,str(iTemple),'AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
			break
		
	return str(iTemple)

def addStateReligionTempleAllCities(iPlayer):
	pPlayer = gc.getPlayer(iPlayer)
	iStateReligion = pPlayer.getStateReligion()
	
	for iCity in range(pPlayer.getNumCities()):
		pCity = pPlayer.getCity(iCity)
		MyTemple = str(getReligionTemple(iStateReligion))
		if not pCity.isHasBuilding(gc.getInfoTypeForString(MyTemple)):
			pCity.setNumRealBuilding(gc.getInfoTypeForString(MyTemple), 1)
	
	return

def getReligionShrine(iStateReligion):
	# Returns the Player's State Religion Shrine Name
	pShrine = -1
	ldata = {
		"RELIGION_JUDAISM": "BUILDING_JEWISH_SHRINE",
		"RELIGION_CHRISTIANITY": "BUILDING_CHRISTIAN_SHRINE",
		"RELIGION_ISLAM": "BUILDING_ISLAMIC_SHRINE",
		"RELIGION_HINDUISM": "BUILDING_HINDU_SHRINE",
		"RELIGION_BUDDHISM": "BUILDING_BUDDHIST_SHRINE",
		"RELIGION_CONFUCIANISM": "BUILDING_CONFUCIAN_SHRINE",
		"RELIGION_TAOISM": "BUILDING_TAOIST_SHRINE"
	}

	for szReligion, iShrine in ldata.iteritems():
		iReligion = gc.getInfoTypeForString(szReligion)
		if iReligion == iStateReligion:
			pShrine = str(iShrine)
			break
		
	return str(iShrine)

def hasStateReligionShrine(iPlayer):
	# True if the player has the state Religion Shrine
	# False if the player does not have the state Religion Shrine
	pPlayer = gc.getPlayer(iPlayer)
	iStateReligion = pPlayer.getStateReligion()
	FoundStateShrine = False
	
	if iStateReligion:
		MyShrine = getReligionShrine(iStateReligion)
				
		for iCity in range(pPlayer.getNumCities()):
			pCity = pPlayer.getCity(iCity)
			if pCity.isHasBuilding(gc.getInfoTypeForString(MyShrine)):	
				FoundStateShrine = True
				break
					
	return FoundStateShrine
	
def OCHasNonStateShrine(Player, iBuilding):
	iStateReligion = Player.getStateReligion()
	FoundNonStateShrine = False
	lShrines = [
		"BUILDING_JEWISH_SHRINE",
		"BUILDING_CHRISTIAN_SHRINE",
		"BUILDING_ISLAMIC_SHRINE",
		"BUILDING_HINDU_SHRINE",
		"BUILDING_BUDDHIST_SHRINE",
		"BUILDING_CONFUCIAN_SHRINE",
		"BUILDING_TAOIST_SHRINE"
	]
	
	for iShrine in range( len( lShrines ) ):
		iShrineReligion = gc.getBuildingInfo(iShrine).getPrereqReligion()
		# If the shrine is not the official state religion shrine
		if iShrineReligion != iStateReligion:
			if (iBuilding == CvUtil.findInfoTypeNum(gc.getBuildingInfo,gc.getNumBuildingInfos(), lShrines[iShrine] )):
				FoundNonStateShrine = True
				break
	
	return FoundNonStateShrine

def AIAttitudeAdjustment(iPlayer, iRequiredReligion, intAdjustment, bDeclareWar):
	# Increases anger for Civs who share the religion purged. 
	# Friendly: 10 or above; Pleased: 3 to 9; Cautious: -2 to 2; Annoyed: -9 to -3; Furious: -10 and below
	# AI Civs who share the religion purged, will declare war if Holy City or Religious Shrine is destroyed 
	eCivicTypeReligion = gc.getInfoTypeForString('CIVICOPTION_RELIGION')
	eCivicTheocracy = gc.getInfoTypeForString('CIVIC_THEOCRACY')
	CvRunTheocracyDeclaredWarMsg = False
		
	for AIPlayer in range(gc.getMAX_PLAYERS()):		
		if AIPlayer != iPlayer:
			AIpPlayer = gc.getPlayer(AIPlayer)
			if not AIpPlayer.isNone() and not AIpPlayer.isBarbarian() and not AIpPlayer.isHuman( ) and AIpPlayer.isAlive():
				if AIpPlayer.getStateReligion( ) == iRequiredReligion:
					PyPlayer(AIPlayer).AI_changeAttitude( iPlayer, intAdjustment )
					#if intAdjustment == -3 or intAdjustment == -7:
					if bDeclareWar == 1:
						# Does the AI Civ have the Theocracy Civic ***********
						if AIpPlayer.getCivics(eCivicTypeReligion) == eCivicTheocracy:
							AIpPlayerTeam =	gc.getTeam(AIpPlayer.getTeam())
							if (not AIpPlayerTeam.isAtWar(iPlayer)):
								# -3 Attitude adjustments means a Holy City and/or a Shrine is being destroyed.
								if intAdjustment == -3:
									# Declare total war
									AIpPlayerTeam.declareWar(iPlayer, false, WarPlanTypes.WARPLAN_TOTAL)
									CvRunTheocracyDeclaredWarMsg = True
								
								elif intAdjustment == -7:
									# Declare Limited war
									AIpPlayerTeam.declareWar(iPlayer, false, WarPlanTypes.WARPLAN_LIMITED)
								
	if CvRunTheocracyDeclaredWarMsg:
		# iPlayer is the Civ who destroyed the Holy City
		# iRequiredReligion is the state religion of the Holy City
		CyMessageControl().sendModNetMessage(200, iPlayer, iRequiredReligion, -1, -1)
		
	return

def doInquisitorPersecution( pCity, pUnit ):
	pPlayer = gc.getPlayer( pCity.getOwner( ) )
	iPlayer = pPlayer.getID( )
	iStateReligion = pPlayer.getStateReligion( )
	iHC = 0
	
	# gets a list of all religions in the city except state religion
	CyInterface().playGeneralSound("AS3D_UN_CHRIST_MISSIONARY_ACTIVATE")
	lCityReligions = [ ]
	for iReligionLoop in range(gc.getNumReligionInfos( )):
		if pCity.isHasReligion( iReligionLoop ):
			if iStateReligion != iReligionLoop:
				lCityReligions.append( iReligionLoop )
				iHC = 0
				if pCity.isHolyCityByType(iReligionLoop):
					iHC = -50
			else:
				if pCity.isHolyCityByType(iReligionLoop):
					iHC = 10
	
	# Does Persecution succeed
	irandom = gc.getGame().getSorenRandNum(100,"")
	if irandom < 95 - ((len( lCityReligions ))*5) + iHC:
		
		# Removes all non-state Religious Buildings from the City
		RemoveAllNonStateReligiousBuildings(pPlayer, iStateReligion, pCity)
		# Remove Non-State Religions from City
		RemoveAllNonStateReligions(pPlayer, iStateReligion, pCity)
		CyInterface().addMessage(CyGame().getActivePlayer(),False,25,CyTranslator().getText("TXT_KEY_MESSAGE_INQUISITION",(pCity.getName(),)),"AS2D_PLAGUE",InterfaceMessageTypes.MESSAGE_TYPE_INFO,pUnit.getButton(),ColorTypes(8),pCity.getX(),pCity.getY(),True,True)
					
	else:
		# Persecution fails
		CyInterface().addMessage(CyGame().getActivePlayer(),False,25,CyTranslator().getText("TXT_KEY_MESSAGE_INQUISITION_FAIL",(pCity.getName(),)),"AS2D_SABOTAGE",InterfaceMessageTypes.MESSAGE_TYPE_INFO,pUnit.getButton(),ColorTypes(7),pCity.getX(),pCity.getY(),True,True)
		
	# Unit expended
	pUnit.kill( 0, -1 )
	
def getRandomNumber(int):
	return CyGame().getSorenRandNum(int, "Gods_CvGameUtils")
	
def doInquisitorCore_AI( pUnit ):
	iOwner = pUnit.getOwner( )
	iStateReligion = gc.getPlayer( iOwner ).getStateReligion( )
	lCities = PyPlayer( iOwner ).getCityList( )		
								
	#Looks to see if the AI controls a City that has a non-State Religion
	for iCity in range( len( lCities ) ):
		for iReligion in range( gc.getNumReligionInfos( ) ):
			if iReligion != iStateReligion:
				pCity = gc.getPlayer( iOwner ).getCity( lCities[ iCity ].getID( ) )
				if pCity.isHasReligion( iReligion ) and pCity.isHasReligion( iStateReligion ):
					if not pCity.isHolyCityByType( iReligion ):
						#Makes the unit move to the City and purge it
						if pUnit.generatePath( pCity.plot( ), 0, False, None ):
							return
		
	#Looks to see if the AI controls a Holy City that is not the State Religion
	for iCity in range( len( lCities ) ):
		for iReligion in range( gc.getNumReligionInfos( ) ):
			if iReligion != iStateReligion:
				pCity = gc.getPlayer( iOwner ).getCity( lCities[ iCity ].getID( ) )
				if pCity.isHolyCityByType( iReligion ) and pCity.isHasReligion( iStateReligion ):
					# Verify option for Inquisitors to remove a non-state Holy City
					if isOC_INQUISITOR_CAN_REMOVE_HOLY_CITY():
						#Makes the unit move to the City and purge it
						if pUnit.generatePath( pCity.plot( ), 0, False, None ):
							doHolyCitySeekAndDestroy(pUnit, pCity)
							return
							
def doHolyCitySeekAndDestroy(pUnit, pCity ):
	Gods = CvEventInterface.getEventManager( )
		
	if isInquisitionConditions(pCity.getOwner()):
		if pUnit.getX( ) != pCity.getX( ) or pUnit.getY( ) != pCity.getY( ):
			pUnit.getGroup().pushMission(MissionTypes.MISSION_MOVE_TO, pCity.getX( ), pCity.getY( ), 0, False, True, MissionAITypes.NO_MISSIONAI, pUnit.plot(), pUnit)
		else:
			Gods.doInquisitorPersecution(pCity, pUnit)

def isInquisitionConditions(playerID):
	# These are conditions which prevent an inquisition
	pPlayer = gc.getPlayer(playerID)

	if not gc.getTeam(pPlayer.getTeam()).isHasTech(gc.getInfoTypeForString('TECH_THEOLOGY')):
		return False

	# If player does not have a State Religion
	if pPlayer.getStateReligion( ) < 0:
		return False

	# If Player has one of the prohibited Civics	
	if hasProhibitedCivic(playerID):
		return False

	return True

def hasProhibitedCivic(playerID):
	# Returns True if the player has a prohibited Civic
	# Returns False if the player does not have a prohibited Civic
	pPlayer = gc.getPlayer(playerID)
	bFoundProhibitedCivic = False
	lProhibitedCivics = [
		"CIVIC_PAGANISM",
		"CIVIC_PACIFISM",
		"CIVIC_FREE_RELIGION"		
	]
	
	for iCivic in range( len( lProhibitedCivics ) ):
		MyCivic = str(lProhibitedCivics[iCivic])
		if (pPlayer.isCivic(gc.getInfoTypeForString(MyCivic))):
			bFoundProhibitedCivic = True
			#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'Found Probibited Civic!','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
			break
			
	return bFoundProhibitedCivic
	
def showInquisitionButton(pUnit):
	pUnitOwner = gc.getPlayer(pUnit.getOwner())
	iStateReligion = pUnitOwner.getStateReligion()
	iUnitType = pUnit.getUnitType()
	ProceedWithInquisition = False
	zShowButton = False
	
	if iStateReligion:
		MyXInquisitor = str(getReligionInquisitor(iStateReligion))
		InquisitorType = CvUtil.findInfoTypeNum(gc.getUnitInfo, gc.getNumUnitInfos(), MyXInquisitor)		
		if iUnitType == InquisitorType:
			pCity = gc.getMap().plot( pUnit.getX(), pUnit.getY() ).getPlotCity()
			pCityPlayer = gc.getPlayer(pCity.getOwner())
			if ( pCity.getOwner( ) == pUnit.getOwner( ) ) or ( gc.getTeam( pCityPlayer.getTeam( ) ).isVassal( gc.getPlayer( pUnit. getOwner( ) ).getTeam( ) ) ): 
				ProceedWithInquisition = True
			elif isOC_FOREIGN_INQUISITIONS():
				#Foriegn Inquisition Check
				if (pCity.getOwner() != pUnit.getOwner()):
					iPlayerA = pUnit.getOwner( )
					iPlayerB = pCity.getOwner( )
					if hasOpenBordersAgreement(iPlayerA, iPlayerB):
						if hasMatchingStateReligion(iPlayerA, iPlayerB):
							ProceedWithInquisition = True
							
			if ProceedWithInquisition:
				if pCity.isHasReligion(iStateReligion):
					for iReligionLoop in range(gc.getNumReligionInfos( )):
						if pCity.isHasReligion(iReligionLoop):
							if iReligionLoop != iStateReligion:
								# If game option prevents Inquisition of Holy City.
								if not isOC_INQUISITOR_CAN_REMOVE_HOLY_CITY():
									# Does City Have one or more non-state religions that are not Holy City religions
									if ocCityHasNonStateReligion(pCity, iStateReligion):
										zShowButton = True
								elif isOC_INQUISITOR_CAN_REMOVE_HOLY_CITY():
									zShowButton = True

	return zShowButton
	
def TheocracyHolyWaronClickedCallback(argsList):
	iButtonId = argsList[0]
	iData1 = argsList[1]
	iData2 = argsList[2]
	iData3 = argsList[3]
	iData4 = argsList[4]
	szText = argsList[5]
	bOption1 = argsList[6]
	bOption2 = argsList[7]
		
	if iButtonId == 0:
		popupInfo = CyPopupInfo()
		popupInfo.setButtonPopupType(ButtonPopupTypes.BUTTONPOPUP_PYTHON)
		popupInfo.setText(CyTranslator().getText("Together we shall strike back at the infadel who desecrated our Holy City!",()))
		popupInfo.addPythonButton(CyTranslator().getText("Let the crusade begin!", ()), "")
		popupInfo.addPopup(CyGame().getActivePlayer())
		# Execute AI change in Attitude + 7
		AIAttitudeAdjustment(iData1, iData2, +7, False)		
		
	elif iButtonId == 1:
		popupInfo = CyPopupInfo()
		popupInfo.setButtonPopupType(ButtonPopupTypes.BUTTONPOPUP_PYTHON)
		popupInfo.setText(CyTranslator().getText("You shall pay the price for betraying our religious faith. We are now at WAR!",()))
		popupInfo.addPythonButton(CyTranslator().getText("So be it!", ()), "")
		popupInfo.addPopup(CyGame().getActivePlayer())
		# Execute AI change in Attitude - 7 and delare war
		AIAttitudeAdjustment(iData1, iData2, -7, True)	
	
def setLR_Player(bPlayer):
	global LR_Player

def DisplayOCCStatus(iPlayer):
	# Runs the popup Menus for the Game Options
	popupInfo = CyPopupInfo()
	popupInfo.setButtonPopupType(ButtonPopupTypes.BUTTONPOPUP_PYTHON)
						
	szText = CyTranslator().getText("TXT_KEY_OCC_TEXT", ())
	szText += "\n\n"			
	szGreenText = CyTranslator().getColorText("On\n", (), gc.getInfoTypeForString("COLOR_GREEN"))
	szRedText = CyTranslator().getColorText("Off\n", (), gc.getInfoTypeForString("COLOR_RED"))
		
	if isOC_LIMITED_RELIGIONS():
		szText += "LIMITED RELIGIONS: " + szGreenText
	else:
		szText += "LIMITED RELIGIONS: " + szRedText
		
	if isOC_FOREIGN_INQUISITIONS():
		szText += "FOREIGN INQUISITIONS: " + szGreenText
	else:
		szText += "FOREIGN INQUISITIONS: " + szRedText
		
	if isOC_RESPAWN_HOLY_CITIES():
		szText += "RESPAWN HOLY CITIES: " + szGreenText
	else:
		szText += "RESPAWN HOLY CITIES: " + szRedText
		
	if isOC_INQUISITOR_CAN_REMOVE_HOLY_CITY():
		szText += "INQUISITOR CAN REMOVE HOLY CITY: " + szGreenText
	else:
		szText += "INQUISITOR CAN REMOVE HOLY CITY: " + szRedText
		
	popupInfo.setText(szText)
	popupInfo.addPythonButton(CyTranslator().getText("OK", ()), "")
	popupInfo.addPopup(iPlayer)
		
	return
# End Orion's Inquisition Mod
