# # Sid Meier's Civilization 4
# # Copyright Firaxis Games 2007
# # InquisitionGameUtils

import CvUtil
from CvPythonExtensions import *
import CvEventInterface
import CvGameUtils
import Popup as PyPopup
import PyHelpers
import GodsOfOld
import Inquisition

# globals
gc = CyGlobalContext()
PyPlayer = PyHelpers.PyPlayer
PyInfo = PyHelpers.PyInfo
PyCity = PyHelpers.PyCity
PyGame = PyHelpers.PyGame

# Inquisition Mod By Orion Veteran
# Modular Python to eliminate Merging 
class InquisitionGameUtils(CvGameUtils.CvGameUtils):
	def isVictory(self, argsList):
		eVictory = argsList[0]

		if eVictory == gc.getInfoTypeForString("VICTORY_RELIGIOUS"):
			return False
			
	def cannotResearch(self,argsList):
		ePlayer = argsList[0]
		eTech = argsList[1]
		bTrade = argsList[2]
		
		# Optional to allow the AI to better use the wonder: 
		if Inquisition.CvHasBuilding(ePlayer, "BUILDING_WITCHES_HAMMER"):
			if not Inquisition.isBuildingObsolete(ePlayer, "BUILDING_WITCHES_HAMMER"):
				if eTech == gc.getInfoTypeForString("TECH_LIBERALISM"):
					return True
	
	def cannotTrain(self,argsList):
		pCity = argsList[0]
		eUnit = argsList[1]
		bContinue = argsList[2]
		bTestVisible = argsList[3]
		bIgnoreCost = argsList[4]
		bIgnoreUpgrades = argsList[5]
		pPlayer = gc.getPlayer(pCity.getOwner())
		iStateReligion = pPlayer.getStateReligion()
		
		if iStateReligion != -1:
			MyInquisitor = str(Inquisition.getReligionInquisitor(iStateReligion))
			
			if eUnit == gc.getInfoTypeForString(MyInquisitor):
				if not Inquisition.isInquisitionConditions(pCity.getOwner()):
					if not pCity.isHasReligion(iStateReligion):
						return True
							
		return False
			
	def cannotConstruct(self,argsList):
		pCity = argsList[0]
		eBuilding = argsList[1]
		bContinue = argsList[2]
		bTestVisible = argsList[3]
		bIgnoreCost = argsList[4]
		pPlayer = gc.getPlayer(pCity.getOwner())
		iPlayer = pPlayer.getID()
		MyHolyOffice = str(getReligionHolyOffice(iStateReligion))
				
		if eBuilding == gc.getInfoTypeForString(MyHolyOffice):
			if Inquisition.hasProhibitedCivic(iPlayer):
				return True

		return False		
			
	def AI_chooseProduction(self,argsList):
		pCity = argsList[0]
		iOwner = pCity.getOwner( )
		pPlayer = gc.getPlayer( pCity.getOwner( ) )		
		iStateReligion = gc.getPlayer( iOwner ).getStateReligion( )
		iBestReligionPercent = Inquisition.getBestReligionPercent()
		
		# Checks religion percents
		if iStateReligion >= 0 or iBestReligionPercent >= 60:
			MyInquisitor = str(Inquisition.getReligionInquisitor(iStateReligion))		
			#iInquisitor = CvUtil.findInfoTypeNum( gc.getUnitInfo, gc.getNumUnitInfos(), MyInquisitor )
			iInquisitor = gc.getInfoTypeForString(MyInquisitor)
			
			if pCity.canTrain( iInquisitor, 0, 0 ):
				#Increase the odds of building an inquisitor if the city has the state religion and the 
				#the owner of that city has a dangerously unstable city. Note that even 100% odds here
				#does not guarantee an inquisitor is built because the SDK will override this code.
				#For some reason, the question pCity.getRevolutionIndex() cannot be asked in this function
				#because a python error can ensue.
								
				lUnits = PyPlayer( pPlayer.getID( ) ).getUnitList( )
				for iUnit in range( len( lUnits) ):
					# if there are any Inquisitors, don't Build one
					if pPlayer.getUnit( lUnits[ iUnit ].getID( ) ).getUnitType( ) == iInquisitor:
						return False
						
				if Inquisition.getRandomNumber( 2 ) == 0:
					gc.getMap( ).plot( pCity.getX( ), pCity.getY( ) ).getPlotCity( ).pushOrder( OrderTypes.ORDER_TRAIN, iInquisitor, -1, False, False, False, True )
					return True

		return False		
			
	def AI_unitUpdate(self,argsList):
		pUnit = argsList[0]
		iOwner = pUnit.getOwner( )
		pPlayer = gc.getPlayer(iOwner)
		iStateReligion = pPlayer.getStateReligion()
		MyInquisitor = str(Inquisition.getReligionInquisitor(iStateReligion))
		iInquisitor = gc.getInfoTypeForString(MyInquisitor)
		
		if not gc.getPlayer( iOwner ).isHuman( ):
			if pUnit.getUnitType( ) == iInquisitor:
				Inquisition.doInquisitorCore_AI( pUnit )
				return True

		return False
		
	def doHolyCity(self):
		# Runs Third
		# Purpose: Determine if Religion should be allowed to be founded
		# Returns True if religion should not be founded
		# Returns False if religion should be founded (Default)
		
		# If game option is NOT Limited Religions
		if not Inquisition.isOC_LIMITED_RELIGIONS():
			# Allow religion to be founded
			return False
		
		# Stop religion from being founded
		return True

	def doHolyCityTech(self,argsList):
		eTeam = argsList[0]
		ePlayer = argsList[1]
		eTech = argsList[2]
		bFirst = argsList[3]
		eTeam = argsList[0]
		ePlayer = argsList[1]
		eTech = argsList[2]
		bFirst = argsList[3]
		# Runs Second
		# Purpose:  Determine if Religion Popup should be dispalyed
		# Returns True if Religion Popup should not be dispalyed
		# Returning False if Religion Popup should be dispalyed	(Default)		
		
		# If game option is NOT Limited Religions
		if not Inquisition.isOC_LIMITED_RELIGIONS():		
			# Allow the Religion popup to be displayed
			return False
			
		# If game option is Limited Religions
		elif Inquisition.isOC_LIMITED_RELIGIONS():
			# If game option is set to choose religions
			if CyGame().isOption(GameOptionTypes.GAMEOPTION_PICK_RELIGION):
				# Does the player have a Holy City?
				if not Inquisition.OwnsHolyCity(ePlayer):
					# Allow the Religion popup to be displayed
					#CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'Message 2','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/TerrainFeatures/Forest.dds',ColorTypes(8),0,0,False,False)
					return False					
					
		# Stop Religion Popup from being dispalyed
		return True			
	
	def cannotSpreadReligion(self,argsList):
#		 NOTE: error in the actual BTS code
#		iOwner, iUnitID, iReligion, iX, iY = argsList[0]
		iOwner, iUnitID, iReligion, iX, iY = argsList
		
		if Inquisition.CannotSpreadNonStateReligion(iReligion, iX, iY):
			return True
		
		return False

	def getWidgetHelp(self, argsList):
		eWidgetType, iData1, iData2, bOption = argsList

		if iData1 == 665:
			return CyTranslator().getText("TXT_KEY_GODS_INQUISITOR_CLEANSE_MOUSE_OVER", ())

		return u""
			
# End Inquisition Mod









